@@ -141,70 +141,6 @@ sub xpath {
     return $final_val;
 } #xpath
 
-#
-# Returns a list of objects as a result : All objects connected to the one specified
-# by the id.
-#
-# The objects are returned as array refs with 3 fields :
-#   id, class, data
-#
-sub fetch_deep {
-    my( $self, $id, $seen ) = @_;
-
-    $seen ||= {};
-
-    my( $class ) = $self->{DBH}->selectrow_array( "SELECT class FROM objects WHERE id=?", {}, $id );
-    print STDERR Data::Dumper->Dump(["db __LINE__",$self->{DBH}->errstr()]) if $self->{DBH}->errstr();
-
-
-    return undef unless $class;
-    my $obj = [$id,$class];
-    given( $class ) {
-        when('ARRAY') {
-            $obj->[DATA] = [];
-        }
-        default {
-            $obj->[DATA] = {};
-        }
-    }
-
-    $seen->{$id} = $obj;
-
-    given( $class ) {
-        when('ARRAY') {
-            my $res = $self->{DBH}->selectall_arrayref( "SELECT field, ref_id, value FROM field WHERE obj_id=?", {}, $id );
-            print STDERR Data::Dumper->Dump(["db __LINE__",$self->{DBH}->errstr()]) if $self->{DBH}->errstr();
-
-            for my $row (@$res) {
-                my( $idx, $ref_id, $value ) = @$row;
-                $obj->[DATA][$idx] = $ref_id || $value;
-                if( $ref_id ) {
-                    fetch_deep( $ref_id, $seen );
-                }
-            }
-        }
-        when('BIGTEXT') {
-            ($obj->[DATA]) = $self->{DBH}->selectrow_array( "SELECT text FROM big_text WHERE obj_id=?", {}, $id );
-            print STDERR Data::Dumper->Dump(["db __LINE__",$self->{DBH}->errstr()]) if $self->{DBH}->errstr();
-
-        }
-        default {
-            my $res = $self->{DBH}->selectall_arrayref( "SELECT field, ref_id, value FROM field WHERE obj_id=?", {}, $id );
-            print STDERR Data::Dumper->Dump(["db __LINE__",$self->{DBH}->errstr()]) if $self->{DBH}->errstr();
-
-            for my $row (@$res) {
-                my( $field, $ref_id, $value ) = @$row;
-                $obj->[DATA]{$field} = $ref_id || $value;
-                if( $ref_id ) {
-                    fetch_deep( $ref_id, $seen );
-                }
-            }
-        } # hash or object
-    }
-
-    return [values %$seen];
-} #fetch_deep
-
 #
 # Returns a single object specified by the id. The object is returned as a hash ref with id,class,data.
 #
